# This is the HelloWorld class with a single method.


class HelloWorld:
    @staticmethod
    def main(args: List[str]):
        print("Hello, world.")

    def add(a: i32, b: i32):
        return a + b
