// This is the HelloWorld class with a single method.
class HelloWorld {
    public static void main(String[] args) {
        System.out.println("Hello, world.");
    }

    public int add(int a, int b) {
        return a + b;
    }
}
